@@ -80,6 +80,50 @@ r2.lm <- function(model, ...) {
 
 
 
+#' @importFrom stats summary.lm
+#' @export
+r2.aov <- function(model, ...) {
+  model_summary <- stats::summary.lm(model)
+
+  out <- list(
+    R2 = model_summary$r.squared,
+    R2_adjusted = model_summary$adj.r.squared
+  )
+
+  names(out$R2) <- "R2"
+  names(out$R2_adjusted) <- "adjusted R2"
+
+  attr(out, "model_type") <- "Anova"
+  structure(class = "r2_generic", out)
+}
+
+
+
+#' @importFrom stats pf
+#' @export
+r2.mlm <- function(model, ...) {
+  model_summary <- summary(model)
+
+  out <- lapply(names(model_summary), function(i) {
+    tmp <- list(
+      R2 = model_summary[[i]]$r.squared,
+      R2_adjusted = model_summary[[i]]$adj.r.squared,
+      Response = sub("Response ", "", i)
+    )
+    names(tmp$R2) <- "R2"
+    names(tmp$R2_adjusted) <- "adjusted R2"
+    names(tmp$Response) <- "Response"
+    tmp
+  })
+
+  names(out) <- names(model_summary)
+
+  attr(out, "model_type") <- "Multivariate Linear"
+  structure(class = "r2_mlm", out)
+}
+
+
+
 #' @importFrom insight model_info
 #' @export
 r2.glm <- function(model, ...) {
@@ -154,6 +198,9 @@ r2.bracl <- r2.censReg
 #' @export
 r2.brmultinom <- r2.censReg
 
+#' @export
+r2.bife <- r2.censReg
+
 
 
 
@@ -272,6 +319,20 @@ r2.betareg <- function(model, ...) {
 }
 
 
+#' @export
+r2.rma <- function(model, ...) {
+  s <- summary(model)
+
+  if (is.null(s$R2)) {
+    return(NULL)
+  }
+
+  out <- list(R2 = s$R2 / 100)
+  attr(out, "model_type") <- "Meta-Analysis"
+  structure(class = "r2_generic", out)
+}
+
+
 
 #' @export
 r2.feis <- function(model, ...) {
@@ -422,6 +483,17 @@ r2.mmclogit <- function(model, ...) {
 
 
 
+#' @export
+r2.Arima <- function(model, ...) {
+  if (!requireNamespace("forecast", quietly = TRUE)) {
+    list(R2 = NA)
+  } else {
+    list(R2 = stats::cor(stats::fitted(model), insight::get_data(model))^2)
+  }
+}
+
+
+
 #' @export
 r2.plm <- function(model, ...) {
   model_summary <- summary(model)
@@ -459,3 +531,10 @@ r2.vglm <- function(model, ...) {
 
 #' @export
 r2.vgam <- r2.vglm
+
+
+
+#' @export
+r2.DirichletRegModel <- function(model, ...) {
+  list("R2_Nagelkerke" = r2_nagelkerke(model))
+}
